BBC NEWS | News Front Page
Description: Get the latest BBC World news: international news, features and analysis from Africa, Americas, South Asia, Asia-Pacific, Europe and the Middle East.
Keywords: BBC, News, BBC News, news online, world, uk, international, foreign, british, online, service

Accessibility links

- Low graphics
- Skip to content
- Skip to local navigation
- Skip to bbc.co.uk navigation
- Skip to bbc.co.uk search
- Help
- Accessibility Help
- Access keys help

# BBC News Updated every minute of every day

One-Minute World News

News Front Page Africa Americas Asia-Pacific Europe Middle East South Asia UK Business Health Science & Environment Technology Entertainment Also in the news ----------------- Video and Audio ----------------- Programmes Have Your Say In Pictures Country Profiles Special Reports ### Related BBC sites Sport Weather On This Day Editors' Blog BBC World Service Languages Arabic Espanol Russian Chinese More |
Page last updated at 12:11 GMT, Friday, 26 February 2010 | News Feeds
|  | Suicide attack on Afghan capital Explosions and gunfire in the centre of Afghanistan's capital, Kabul, leave at least 17 people dead, officials say. Explosion aftermath In pictures: Kabul attack Eyewitness: 'Huge explosion'
Thai court giving Thaksin ruling Thai judges are giving their verdict on whether to seize billions of dollars' worth of assets from ex-PM Thaksin Shinawatra's family. |  | Young 'exposed to sexual images' British children are being over-exposed to sexual imagery and tighter media controls are needed, a government report says.
VIDEO NEWS
Killer whale filmed before attack Johnny Depp at Wonderland premiere |  | Lights go out on Hugo Chavez Roller cops and big dogs - it's Odd Box
FEATURES, VIEWS, ANALYSIS
Tailor of Baghdad Iraq tries to the restrict market in military uniforms |  | It's quiz time! Is India's law mightier than the 'Gandhi' pen? |  | I Owe Who Who has lent all this money to Britain?
MORE FROM BBC NEWS
BUSINESS UK economic growth revised upward Wall Street's Greece role probed Bad debts of £24bn knock Lloyds |  | TECHNOLOGY Tiny ear listens to hidden worlds 'Broadband grants' for homes plea Botnet shutdown divides experts
ENTERTAINMENT Star Trek actor's son found dead BBC 'axing 6 music' report claims HEALTH Group therapy 'eases back pain' |  | SCIENCE & ENVIRONMENT Lasers lift dirt of ages from art 'People must learn from Haiti tsunami'
AROUND THE WORLD NOW
AFRICA Egypt cruise crash kills sailors Ivory Coast poll commission named AMERICAS US health summit ends in deadlock SeaWorld killer whale 'can stay' ASIA-PACIFIC Australia green minister demoted Japan Airlines reports huge loss |  | EUROPE Iceland repayment talks collapse EU: Settlement goods not Israeli MIDDLE EAST Iran 'militant' claims US support Australia anger at Dubai killing SOUTH ASIA Court 'bans Taliban extradition' India to review economy stimulus
NEWS FROM THE UK
Woman jailed for sex with boy, 12 A woman aged 36 is jailed for nine years after admitting having sex with a 12-year-old boy nearly 200 times. UK soldier killed in Afghanistan Death charge hospital admits breach |  | Court lifts ban on MI5 criticism The Court of Appeal decides to publish a paragraph criticising MI5 in a judgement involving Binyam Mohamed. 85-year-old jailed for stabbing Snow leaves homes without power
FEATURES, VIEWS, ANALYSIS
Battle lines Summit raises stakes in US health reform battle |  | Bad reputation Dubai murder wins Mossad the wrong kind of press |  | Coup confusion Rumours of plots abound as Thailand judges Thaksin
| OTHER TOP STORIES New charges in Turkey 'coup plot' UN slams Libya anti-Swiss 'jihad' Deadly crush at Timbuktu mosque Burma's Suu Kyi appeal rejected Whaling 'worsens carbon release' Brazil baby dies 'as doctors row' ALSO IN THE NEWS Kapow! Batman comic ousts Superman in auction record WINTER OLYMPICS 2010 Canada outclass US to take gold Team GB chiefs defend medal tally Kim storms to figure skating gold SPORT HEADLINES Portsmouth enter administration Live text - F1 testing HAVE YOUR SAY Can India-Pakistan talks succeed? #### MOST POPULAR STORIES NOW SHARED READ WATCHED/LISTENED 'Most unfortunate names' revealed Vast iceberg 'a threat to oceans' Greece angers Germany in gold row Young 'exposed to sexual imagery' Whaling 'worsens carbon release' SHARED READ WATCHED/LISTENED Star Trek actor's son found dead Woman jailed for sex with boy, 12 Young 'exposed to sexual imagery' 'Most unfortunate names' revealed UN slams Libya anti-Swiss 'jihad' Brazil baby dies 'as doctors row' Suicide attack on Afghan capital Vast iceberg 'a threat to oceans' Dubai killing shines unwelcome spotlight on Mossad Weekly world news quiz SHARED READ WATCHED/LISTENED Killer whale filmed before attack Lights go out on Hugo Chavez 'We thought they were playing' One-minute World News Stars at premiere of Wonderland film 'The police tried to stop them' Jumpers knitted for bald chickens SeaWorld trainer had 'dream' job Greece angers Germany in gold row Media 'sexualises' young girls RADIO AND TV PROGRAMMES World Service Are South Korea's robot English teachers key to fluency? World News America Cuba's 'health diplomacy' winning hearts and minds Latest World Service bulletin Listen to the World Service World News America BBC World News WORLD WEATHER
#### ELSEWHERE ON THE BBC

Skip to top

#### PRODUCTS & SERVICES

- E-mail news
- Mobiles
- Alerts
- News feeds
- Podcasts

Search term:

## Explore the BBC

## Site links

- News Sources
- About BBC News

## BBC links

- About the BBC
- BBC Help
- Contact Us
- Accessibility Help
- Terms of Use
- Jobs
- Privacy & Cookies

© MMX

The BBC is not responsible for the content of external internet sites.

This page is best viewed in an up-to-date web browser with style sheets (CSS) enabled. While you will be able to view the content of this page in your current browser, you will not be able to get the full visual experience. Please consider upgrading your browser software or enabling style sheets (CSS) if you are able to do so.